@@ -13,7 +13,7 @@ Usage::
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, overload
+from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_networkmanager.paginator import (
     DescribeGlobalNetworksPaginator,
@@ -66,19 +66,19 @@ __all__ = ("NetworkManagerClient",)
 
 
 class Exceptions:
-    AccessDeniedException: Boto3ClientError
-    ClientError: Boto3ClientError
-    ConflictException: Boto3ClientError
-    InternalServerException: Boto3ClientError
-    ResourceNotFoundException: Boto3ClientError
-    ServiceQuotaExceededException: Boto3ClientError
-    ThrottlingException: Boto3ClientError
-    ValidationException: Boto3ClientError
+    AccessDeniedException: Type[Boto3ClientError]
+    ClientError: Type[Boto3ClientError]
+    ConflictException: Type[Boto3ClientError]
+    InternalServerException: Type[Boto3ClientError]
+    ResourceNotFoundException: Type[Boto3ClientError]
+    ServiceQuotaExceededException: Type[Boto3ClientError]
+    ThrottlingException: Type[Boto3ClientError]
+    ValidationException: Type[Boto3ClientError]
 
 
 class NetworkManagerClient:
     """
-    [NetworkManager.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client)
+    [NetworkManager.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client)
     """
 
     exceptions: Exceptions
@@ -87,19 +87,19 @@ class NetworkManagerClient:
         self, CustomerGatewayArn: str, GlobalNetworkId: str, DeviceId: str, LinkId: str = None
     ) -> AssociateCustomerGatewayResponseTypeDef:
         """
-        [Client.associate_customer_gateway documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.associate_customer_gateway)
+        [Client.associate_customer_gateway documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.associate_customer_gateway)
         """
 
     def associate_link(
         self, GlobalNetworkId: str, DeviceId: str, LinkId: str
     ) -> AssociateLinkResponseTypeDef:
         """
-        [Client.associate_link documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.associate_link)
+        [Client.associate_link documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.associate_link)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.can_paginate)
         """
 
     def create_device(
@@ -115,14 +115,14 @@ class NetworkManagerClient:
         Tags: List[TagTypeDef] = None,
     ) -> CreateDeviceResponseTypeDef:
         """
-        [Client.create_device documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.create_device)
+        [Client.create_device documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.create_device)
         """
 
     def create_global_network(
         self, Description: str = None, Tags: List[TagTypeDef] = None
     ) -> CreateGlobalNetworkResponseTypeDef:
         """
-        [Client.create_global_network documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.create_global_network)
+        [Client.create_global_network documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.create_global_network)
         """
 
     def create_link(
@@ -136,7 +136,7 @@ class NetworkManagerClient:
         Tags: List[TagTypeDef] = None,
     ) -> CreateLinkResponseTypeDef:
         """
-        [Client.create_link documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.create_link)
+        [Client.create_link documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.create_link)
         """
 
     def create_site(
@@ -147,55 +147,55 @@ class NetworkManagerClient:
         Tags: List[TagTypeDef] = None,
     ) -> CreateSiteResponseTypeDef:
         """
-        [Client.create_site documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.create_site)
+        [Client.create_site documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.create_site)
         """
 
     def delete_device(self, GlobalNetworkId: str, DeviceId: str) -> DeleteDeviceResponseTypeDef:
         """
-        [Client.delete_device documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.delete_device)
+        [Client.delete_device documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.delete_device)
         """
 
     def delete_global_network(self, GlobalNetworkId: str) -> DeleteGlobalNetworkResponseTypeDef:
         """
-        [Client.delete_global_network documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.delete_global_network)
+        [Client.delete_global_network documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.delete_global_network)
         """
 
     def delete_link(self, GlobalNetworkId: str, LinkId: str) -> DeleteLinkResponseTypeDef:
         """
-        [Client.delete_link documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.delete_link)
+        [Client.delete_link documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.delete_link)
         """
 
     def delete_site(self, GlobalNetworkId: str, SiteId: str) -> DeleteSiteResponseTypeDef:
         """
-        [Client.delete_site documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.delete_site)
+        [Client.delete_site documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.delete_site)
         """
 
     def deregister_transit_gateway(
         self, GlobalNetworkId: str, TransitGatewayArn: str
     ) -> DeregisterTransitGatewayResponseTypeDef:
         """
-        [Client.deregister_transit_gateway documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.deregister_transit_gateway)
+        [Client.deregister_transit_gateway documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.deregister_transit_gateway)
         """
 
     def describe_global_networks(
         self, GlobalNetworkIds: List[str] = None, MaxResults: int = None, NextToken: str = None
     ) -> DescribeGlobalNetworksResponseTypeDef:
         """
-        [Client.describe_global_networks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.describe_global_networks)
+        [Client.describe_global_networks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.describe_global_networks)
         """
 
     def disassociate_customer_gateway(
         self, GlobalNetworkId: str, CustomerGatewayArn: str
     ) -> DisassociateCustomerGatewayResponseTypeDef:
         """
-        [Client.disassociate_customer_gateway documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.disassociate_customer_gateway)
+        [Client.disassociate_customer_gateway documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.disassociate_customer_gateway)
         """
 
     def disassociate_link(
         self, GlobalNetworkId: str, DeviceId: str, LinkId: str
     ) -> DisassociateLinkResponseTypeDef:
         """
-        [Client.disassociate_link documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.disassociate_link)
+        [Client.disassociate_link documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.disassociate_link)
         """
 
     def generate_presigned_url(
@@ -206,7 +206,7 @@ class NetworkManagerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.generate_presigned_url)
         """
 
     def get_customer_gateway_associations(
@@ -217,7 +217,7 @@ class NetworkManagerClient:
         NextToken: str = None,
     ) -> GetCustomerGatewayAssociationsResponseTypeDef:
         """
-        [Client.get_customer_gateway_associations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.get_customer_gateway_associations)
+        [Client.get_customer_gateway_associations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.get_customer_gateway_associations)
         """
 
     def get_devices(
@@ -229,7 +229,7 @@ class NetworkManagerClient:
         NextToken: str = None,
     ) -> GetDevicesResponseTypeDef:
         """
-        [Client.get_devices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.get_devices)
+        [Client.get_devices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.get_devices)
         """
 
     def get_link_associations(
@@ -241,7 +241,7 @@ class NetworkManagerClient:
         NextToken: str = None,
     ) -> GetLinkAssociationsResponseTypeDef:
         """
-        [Client.get_link_associations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.get_link_associations)
+        [Client.get_link_associations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.get_link_associations)
         """
 
     def get_links(
@@ -255,7 +255,7 @@ class NetworkManagerClient:
         NextToken: str = None,
     ) -> GetLinksResponseTypeDef:
         """
-        [Client.get_links documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.get_links)
+        [Client.get_links documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.get_links)
         """
 
     def get_sites(
@@ -266,7 +266,7 @@ class NetworkManagerClient:
         NextToken: str = None,
     ) -> GetSitesResponseTypeDef:
         """
-        [Client.get_sites documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.get_sites)
+        [Client.get_sites documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.get_sites)
         """
 
     def get_transit_gateway_registrations(
@@ -277,29 +277,29 @@ class NetworkManagerClient:
         NextToken: str = None,
     ) -> GetTransitGatewayRegistrationsResponseTypeDef:
         """
-        [Client.get_transit_gateway_registrations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.get_transit_gateway_registrations)
+        [Client.get_transit_gateway_registrations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.get_transit_gateway_registrations)
         """
 
     def list_tags_for_resource(self, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.list_tags_for_resource)
         """
 
     def register_transit_gateway(
         self, GlobalNetworkId: str, TransitGatewayArn: str
     ) -> RegisterTransitGatewayResponseTypeDef:
         """
-        [Client.register_transit_gateway documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.register_transit_gateway)
+        [Client.register_transit_gateway documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.register_transit_gateway)
         """
 
     def tag_resource(self, ResourceArn: str, Tags: List[TagTypeDef]) -> Dict[str, Any]:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.tag_resource)
         """
 
     def untag_resource(self, ResourceArn: str, TagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.untag_resource)
         """
 
     def update_device(
@@ -315,14 +315,14 @@ class NetworkManagerClient:
         SiteId: str = None,
     ) -> UpdateDeviceResponseTypeDef:
         """
-        [Client.update_device documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.update_device)
+        [Client.update_device documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.update_device)
         """
 
     def update_global_network(
         self, GlobalNetworkId: str, Description: str = None
     ) -> UpdateGlobalNetworkResponseTypeDef:
         """
-        [Client.update_global_network documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.update_global_network)
+        [Client.update_global_network documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.update_global_network)
         """
 
     def update_link(
@@ -335,7 +335,7 @@ class NetworkManagerClient:
         Provider: str = None,
     ) -> UpdateLinkResponseTypeDef:
         """
-        [Client.update_link documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.update_link)
+        [Client.update_link documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.update_link)
         """
 
     def update_site(
@@ -346,7 +346,7 @@ class NetworkManagerClient:
         Location: LocationTypeDef = None,
     ) -> UpdateSiteResponseTypeDef:
         """
-        [Client.update_site documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Client.update_site)
+        [Client.update_site documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Client.update_site)
         """
 
     @overload
@@ -354,7 +354,7 @@ class NetworkManagerClient:
         self, operation_name: Literal["describe_global_networks"]
     ) -> DescribeGlobalNetworksPaginator:
         """
-        [Paginator.DescribeGlobalNetworks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Paginator.DescribeGlobalNetworks)
+        [Paginator.DescribeGlobalNetworks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Paginator.DescribeGlobalNetworks)
         """
 
     @overload
@@ -362,13 +362,13 @@ class NetworkManagerClient:
         self, operation_name: Literal["get_customer_gateway_associations"]
     ) -> GetCustomerGatewayAssociationsPaginator:
         """
-        [Paginator.GetCustomerGatewayAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Paginator.GetCustomerGatewayAssociations)
+        [Paginator.GetCustomerGatewayAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Paginator.GetCustomerGatewayAssociations)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_devices"]) -> GetDevicesPaginator:
         """
-        [Paginator.GetDevices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Paginator.GetDevices)
+        [Paginator.GetDevices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Paginator.GetDevices)
         """
 
     @overload
@@ -376,19 +376,19 @@ class NetworkManagerClient:
         self, operation_name: Literal["get_link_associations"]
     ) -> GetLinkAssociationsPaginator:
         """
-        [Paginator.GetLinkAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinkAssociations)
+        [Paginator.GetLinkAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinkAssociations)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_links"]) -> GetLinksPaginator:
         """
-        [Paginator.GetLinks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinks)
+        [Paginator.GetLinks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinks)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_sites"]) -> GetSitesPaginator:
         """
-        [Paginator.GetSites documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Paginator.GetSites)
+        [Paginator.GetSites documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Paginator.GetSites)
         """
 
     @overload
@@ -396,5 +396,5 @@ class NetworkManagerClient:
         self, operation_name: Literal["get_transit_gateway_registrations"]
     ) -> GetTransitGatewayRegistrationsPaginator:
         """
-        [Paginator.GetTransitGatewayRegistrations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayRegistrations)
+        [Paginator.GetTransitGatewayRegistrations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayRegistrations)
         """
